@@ -527,7 +527,7 @@ void concat( struct string *str, char *data )
 void remove_dir( char *name )
 {
    DIR *dir;
-   struct dirent entry, *result;
+   struct dirent *entry;
    char buffer[ MAXPATHLEN + 1 ];
 
    if (( dir = opendir( name )) == NULL )
@@ -539,12 +539,12 @@ void remove_dir( char *name )
       exit( 1 );
    }
 
-   readdir_r( dir, &entry, &result );
-   readdir_r( dir, &entry, &result );
+   readdir( dir );
+   readdir( dir );
 
-   while( ! readdir_r( dir, &entry, &result ) && result != NULL )
+   while(( entry = readdir( dir )) != NULL )
    {
-      snprintf( buffer, sizeof( buffer ), "%s/%s", name, entry.d_name );
+      snprintf( buffer, sizeof( buffer ), "%s/%s", name, entry->d_name );
 
       if ( unlink( buffer ) < 0 )
       {
